@@ -13,13 +13,18 @@
 #include <KLocalizedString>
 #include <QPushButton>
 #include <QStandardPaths>
+#include <QWindow>
+
+using namespace Qt::StringLiterals;
+
+using namespace Qt::StringLiterals;
 
 AccessDialog::AccessDialog(QObject *parent)
     : QuickDialog(parent)
 {
     m_props = {
-        {"iconName", "dialog-question"},
-        {"title", i18n("Request device access")},
+        {u"iconName"_s, u"dialog-question"_s},
+        {u"title"_s, i18n("Request device access")},
     };
 }
 
@@ -53,6 +58,22 @@ void AccessDialog::setTitle(const QString &title)
     m_props.insert(QStringLiteral("title"), title);
 }
 
+void AccessDialog::setChoices(const OptionList &choices)
+{
+    m_props.insert(u"choices"_s, QVariant::fromValue(choices));
+}
+
+Choices AccessDialog::selectedChoices() const
+{
+    auto props = m_theDialog->property("selectedChoices").value<QVariantMap>();
+    Choices choices;
+    choices.reserve(props.size());
+    for (const auto &prop : props.asKeyValueRange()) {
+        choices.emplaceBack(prop.first, prop.second.toString());
+    }
+    return choices;
+}
+
 void AccessDialog::createDialog()
 {
     create(QStringLiteral("qrc:/AccessDialog.qml"), m_props);
