@@ -32,6 +32,8 @@
 #include <KWaylandExtras>
 #include <KWindowSystem>
 
+using namespace Qt::StringLiterals;
+
 AppChooserDialog::AppChooserDialog(const QStringList &choices, const QString &lastUsedApp, const QString &fileName, const QString &mimeName, bool autoRemember)
     : QuickDialog(nullptr)
     , m_model(new AppModel(this))
@@ -39,10 +41,10 @@ AppChooserDialog::AppChooserDialog(const QStringList &choices, const QString &la
     , m_autoRemember(autoRemember)
 {
     QVariantMap props = {
-        {"title", i18nc("@title:window", "Choose Application")},
+        {u"title"_s, i18nc("@title:window", "Choose Application")},
         // fileName is actually the full path, confusingly enough. But showing the
         // whole thing is overkill; let's just show the user the file itself
-        {"mainText", xi18nc("@info", "Choose an application to open <filename>%1</filename>", QUrl::fromLocalFile(fileName).fileName())},
+        {u"mainText"_s, xi18nc("@info", "Choose an application to open <filename>%1</filename>", QUrl::fromLocalFile(fileName).fileName())},
     };
 
     auto filterModel = new AppFilterModel(this);
@@ -286,7 +288,7 @@ void AppFilterModel::setFilter(const QString &text)
 
     if (!m_filter.isEmpty() && m_showOnlyPreferredApps) {
         m_showOnlyPreferredApps = false;
-        emit showOnlyPreferredAppsChanged();
+        Q_EMIT showOnlyPreferredAppsChanged();
     }
 
     invalidate();
